Products.zms.zmscontainerobject.ZMSContainerObject

Package Products :: Package zms :: Module zmscontainerobject :: Class ZMSContainerObject |
[frames] | no frames]

# Class ZMSContainerObject

                                                                                                                                                                                                          ZMSItem.ZMSItem --+
                                                                                                                                                                                                                            |
                                                                                                                                                                               ZCatalog.CatalogPathAwareness.CatalogAware --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                          _accessmanager.AccessableObject --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                              _versionmanager.VersionItem --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                          ZMSWorkflowItem.ZMSWorkflowItem --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                 _copysupport.CopySupport --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                    _cachemanager.ReqBuff --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                             _deprecatedapi.DeprecatedAPI --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                    _multilangmanager.MultiLanguageObject --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                   _exportable.Exportable --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                       _objattrs.ObjAttrs --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                 _objchildren.ObjChildren --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                     _objinputs.ObjInputs --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                       _objtypes.ObjTypes --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                 _pathhandler.PathHandler --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                      _textformatmanager.TextFormatObject --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                           _zreferableitem.ZReferableItem --+
                                                                                                                                                                                                                            |
                                                                                                                                                                                                          zmsobject.ZMSObject --+
                                                                                                                                                                                                                                |
    ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+       |
                                                                                                                                                                                                                        |       |
                                                                                                                                                                          AccessControl.PermissionMapping.RoleManager --+       |
                                                                                                                                                                                                                        |       |
                                                                                                                                                                                    AccessControl.rolemanager.RoleManager --+   |
                                                                                                                                                                                                                            |   |
                                                                                                                                                                                                         OFS.role.RoleManager --+
                                                                                                                                                                                                                                |
                                                                                                                                                                                           _accessmanager.AccessableContainer --+
                                                                                                                                                                                                                                |
                                                                                                                                                                                      _versionmanager.VersionManagerContainer --+
                                                                                                                                                                                                                                |
                                                                                                                                                                                                                               ZMSContainerObject

Instance Methods
manage_addZMSCustom(self, meta_id, values={}, REQUEST=None) |
zmi_manage_addZMSCustom(self, meta_id, values={}, REQUEST=None) |
manage_addZMSObject(self, meta_id, values, REQUEST) |
moveObjsToTrashcan(self, ids, REQUEST) |
manage_eraseObjs(self, lang, ids, REQUEST, RESPONSE=None) Delete a subordinate object physically: The objects specified in 'ids' get deleted. |
manage_undoObjs(self, lang, ids, REQUEST, RESPONSE=None) Undo a subordinate object: The objects specified in 'ids' get undone (changes are rolled-back). |
manage_deleteObjs(self, lang, ids, REQUEST, RESPONSE=None) Delete a subordinate object logically: The objects specified in 'ids' get deleted (moved to trashcan). |
`string` |
getContentType(self, REQUEST) Returns MIME-type (text/html). |
manage_ajaxDragDrop(self, lang, target, REQUEST, RESPONSE) ZMSContainerObject.manage_ajaxDragDrop |
`zmsobject.ZMSObject` |
getFirstPage(self, REQUEST, incResource=False, root=None) Returns the first page of the tree from root (or document-element if root is not given). |
getPrevPage(self, REQUEST, incResource=False, root=None) |
getNextPage(self, REQUEST, incResource=False, root=None) |
`zmsobject.ZMSObject` |
getLastPage(self, REQUEST, incResource=False, root=None) Returns the last page of the tree from root (or document-element if root is not given). |
manage_ajaxZMIActions(self, context_id, REQUEST, RESPONSE) Returns ZMI actions. |
`string` |
getNavItems(self, current, REQUEST, opt={}, depth=0) Returns html-formatted (unordered) list of navigation-items. |
getNavElements(self, REQUEST, expand_tree=1, current_child=None, subElements=[]) |
getIndexNavElements(self, REQUEST) |
filteredTreeNodes(self, REQUEST, meta_types, order_by=None, order_dir=None, max_len=None, recursive=True) Returns a NodeList that contains all visible children of this subtree in correct order. |
firstFilteredChildNode(self, REQUEST={}, meta_types=None) Returns the first visible child of this node. |
filteredChildNodes(self, REQUEST={}, meta_types=None) Returns a NodeList that contains all visible children of this node in correct order. |
getChildNodes(self, REQUEST=None, meta_types=None, reid=None) Returns a NodeList that contains all children of this node in correct order. |
normalizeSortIds(self, id_prefix='e') |
getNewSortId(self) |
manage_addZMSCustomDefault(self, lang, id_prefix, _sort_id, REQUEST, RESPONSE) Add default. |
manage_addZMSModule(self, lang, _sort_id, custom, REQUEST, RESPONSE) Add module. |
Inherited from `zmsobject.ZMSObject`: `__init__`, `__proxy__`, `ajaxGetBodyContent`, `ajaxGetChildNodes`, `ajaxGetNode`, `ajaxGetNodes`, `ajaxGetParentNodes`, `aq_absolute_url`, `breadcrumbs_obj_path`, `changeProperties`, `display_icon`, `display_type`, `f_css_defaults`, `getBodyContent`, `getDCCoverage`, `getDCDescription`, `getDeclId`, `getDeclUrl`, `getHref2Html`, `getHref2IndexHtml`, `getHref2IndexHtmlInContext`, `getLevel`, `getPageExt`, `getParentByDepth`, `getParentByLevel`, `getParentNode`, `getSelf`, `getSortId`, `getTitle`, `getTitlealt`, `getTreeNodes`, `getType`, `get_conf_blob`, `get_oid`, `get_request_context`, `get_size`, `get_uid`, `icon`, `isAncestor`, `isFeatureEnabled`, `isMetaType`, `isModifiedInParentLanguage`, `isPage`, `isPageContainer`, `isPageElement`, `isResource`, `isTranslated`, `isVisible`, `is_child_of`, `is_resource`, `is_translated`, `is_visible`, `manage_ajaxGetChildNodes`, `manage_changeProperties`, `manage_executeMetacmd`, `manage_moveObjDown`, `manage_moveObjToPos`, `manage_moveObjUp`, `printHtml`, `renderShort`, `setSortId`, `set_request_context`, `set_uid`, `title`, `xmlGetParent`, `xmlOnCharacterData`, `xmlOnEndElement`, `xmlOnStartElement`, `xmlOnUnknownEndTag`, `xmlOnUnknownStartTag`, `zmi_css_defaults` Inherited from `OFS.role.RoleManager`: `manage_access`, `manage_acquiredPermissions`, `manage_addLocalRoles`, `manage_changePermissions`, `manage_defined_roles`, `manage_delLocalRoles`, `manage_editRoles`, `manage_permission`, `manage_role`, `manage_setLocalRoles` Inherited from `AccessControl.rolemanager.RoleManager`: `ac_inherited_permissions`, `access_debug_info`, `acquiredRolesAreUsedBy`, `get_local_roles`, `get_local_roles_for_userid`, `get_valid_userids`, `has_local_roles`, `manage_getUserRolesAndPermissions`, `permission_settings`, `permissionsOfRole`, `possible_permissions`, `rolesOfPermission`, `userdefined_roles`, `users_with_local_role`, `valid_roles`, `validate_roles` Inherited from `AccessControl.PermissionMapping.RoleManager`: `manage_getPermissionMapping`, `manage_setPermissionMapping`

Class Variables
| __administratorPermissions__ = `'manage_system',`
| __ac_permissions__ = `'ZMS Administrator', __administratorPermi`...``
| manage_main = `PageTemplateFile('zpt/ZMSObject/manage_main', gl`...``
| zmi_manage_main_change = `PageTemplateFile('zpt/ZMSContainerObj`...``
| zmi_manage_main_grid = `PageTemplateFile('zpt/ZMSContainerObjec`...``
| manage_container = `PageTemplateFile('zpt/ZMSContainerObject/ma`...``
| manage_properties = `PageTemplateFile('zpt/ZMSObject/manage_mai`...``
| manage_system = `PageTemplateFile('zpt/ZMSContainerObject/manag`...``
| manage_importexport = `PageTemplateFile('zpt/ZMSContainerObject`...``
| PAGES = `0`
| PAGEELEMENTS = `1`
| NOREF = `4`
| NORESOLVEREF = `5`
Inherited from `zmsobject.ZMSObject`: `FORM_LABEL_MANDATORY`, `MISC_ZMS`, `QUOT`, `__doc__`, `f_api_html`, `f_api_top_html`, `f_display_icon`, `f_recordset_grid`, `obj_input_elements`, `obj_input_fields`, `preview_html`, `preview_top_html`, `security`, `spacer_gif`, `zmi_ace_editor`, `zmi_body_footer`, `zmi_body_header`, `zmi_breadcrumbs`, `zmi_breadcrumbs_obj_path`, `zmi_html_foot`, `zmi_html_head`, `zmi_icon`, `zmi_manage_tabs_message`, `zmi_navbar_brand`, `zmi_pagination`, `zmi_tabs`, `zmi_tabs_sub` Inherited from `OFS.role.RoleManager`: `aclAChecked`, `aclEChecked`, `aclPChecked`, `manage_acquiredForm`, `manage_editLocalRoles`, `manage_listLocalRoles`, `manage_options`, `manage_permissionForm`, `manage_reportUserPermissions`, `manage_roleForm`, `selectedRoles`, `smallRolesWidget`, `validRoles` Inherited from `AccessControl.rolemanager.RoleManager`: `__ac_local_roles__`, `__ac_roles__`, `permissionMappingPossibleValues`

Method Details

### manage_eraseObjs(self, lang, ids, REQUEST, RESPONSE=None) |
Delete a subordinate object physically: The objects specified in 'ids' get deleted. Parameters: `lang` - Language-id. `ids` (`string`) - List of object-ids. `REQUEST` (ZPublisher.HTTPRequest) - the triggering request `RESPONSE` (ZPublisher.HTTPResponse) - the triggering request

### manage_undoObjs(self, lang, ids, REQUEST, RESPONSE=None) |
Undo a subordinate object: The objects specified in 'ids' get undone (changes are rolled-back). Parameters: `lang` - Language-id. `ids` (`string`) - List of object-ids. `REQUEST` (ZPublisher.HTTPRequest) - the triggering request `RESPONSE` (ZPublisher.HTTPResponse) - the triggering request

### manage_deleteObjs(self, lang, ids, REQUEST, RESPONSE=None) |
Delete a subordinate object logically: The objects specified in 'ids' get deleted (moved to trashcan). Parameters: `lang` - Language-id. `ids` (`string`) - List of object-ids. `REQUEST` (ZPublisher.HTTPRequest) - the triggering request `RESPONSE` (ZPublisher.HTTPResponse) - the triggering request

### getFirstPage(self, REQUEST, incResource=False, root=None) |
Returns the first page of the tree from root (or document-element if root is not given). Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the first page

### getLastPage(self, REQUEST, incResource=False, root=None) |
Returns the last page of the tree from root (or document-element if root is not given). Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the last page

### manage_ajaxZMIActions(self, context_id, REQUEST, RESPONSE) |
Returns ZMI actions. Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `RESPONSE` (`ZPublisher.HTTPResponse`) - the response

### getNavItems(self, current, REQUEST, opt={}, depth=0) |
Returns html-formatted (unordered) list of navigation-items. Uses the following classes current item is current-element (in-)active items is parent of current-element or current-element restricted item has restricted access Parameters: `current` (`zmsobject.ZMSObject`) - the currently displayed page `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `opt` - the dictionary of options id (`string=''`) id of base ul-element cssclass (`string=''`) css class of base ul-element add_self (`boolean=False`) add self to list deep (`boolean=True`) process child nodes complete (`boolean=False`) process complete subtree maxdepth (`int=100`) limits node list to a given depth getrestricted (`boolean=True`) get is restricted getchildpages (`boolean=True`) get has child-pages Returns: `string` the Html

### filteredTreeNodes(self, REQUEST, meta_types, order_by=None, order_dir=None, max_len=None, recursive=True) |
Returns a NodeList that contains all visible children of this subtree in correct order. If none, this is a empty NodeList.

### filteredChildNodes(self, REQUEST={}, meta_types=None) |
Returns a NodeList that contains all visible children of this node in correct order. If none, this is a empty NodeList.

### getChildNodes(self, REQUEST=None, meta_types=None, reid=None) |
Returns a NodeList that contains all children of this node in correct order. If none, this is a empty NodeList.

Class Variable Details

  ### __ac_permissions__ Value:
      'ZMS Administrator', __administratorPermissions__,

  ### manage_main Value:
      PageTemplateFile('zpt/ZMSObject/manage_main', globals())

  ### zmi_manage_main_change Value:
      PageTemplateFile('zpt/ZMSContainerObject/zmi_manage_main_change', glob
      als())

  ### zmi_manage_main_grid Value:
      PageTemplateFile('zpt/ZMSContainerObject/main_grid', globals())

  ### manage_container Value:
      PageTemplateFile('zpt/ZMSContainerObject/manage_main', globals())

  ### manage_properties Value:
      PageTemplateFile('zpt/ZMSObject/manage_main', globals())

  ### manage_system Value:
      PageTemplateFile('zpt/ZMSContainerObject/manage_system', globals())

  ### manage_importexport Value:
      PageTemplateFile('zpt/ZMSContainerObject/manage_importexport', globals
      ())